==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/da.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: da.php,v 1.16 2005/12/07 15:02:11 bigmichi1 Exp $

# Translated by Jonas Koch Bentzen (understroem.dk).

$text['title']          = 'Systeminformation';

$text['vitals']         = 'Systemenheder';
$text['hostname']       = 'Konisk vrtsnavn';
$text['ip']             = 'IP-adresse, der lyttes p';
$text['kversion']       = 'Kerne-version';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Oppetid';
$text['users']          = 'Antal brugere logget ind lige nu';
$text['loadavg']        = 'Ressourceforbrug - gennemsnit';

$text['hardware']       = 'Hardwareinformation';
$text['numcpu']         = 'Processorer';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cachestrrelse';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'PCI-enheder';
$text['ide']            = 'IDE-enheder';
$text['scsi']           = 'SCSI-enheder';
$text['usb']            = 'USB-enheder';

$text['netusage']       = 'Netvrkstrafik';
$text['device']         = 'Enhed';
$text['received']       = 'Modtaget';
$text['sent']           = 'Afsendt';
$text['errors']         = 'Mislykket/tabt';

$text['memusage']       = 'Hukommelsesforbrug';
$text['phymem']         = 'Fysisk hukommelse';
$text['swap']           = 'Swap';

$text['fs']             = 'Monterede filsystemer';
$text['mount']          = 'Monteret p';
$text['partition']      = 'Partition';

$text['percent']        = 'Procent af kapaciteten';
$text['type']           = 'Type';
$text['free']           = 'Ledig';
$text['used']           = 'Brugt';
$text['size']           = 'Strrelse';
$text['totals']         = 'I alt';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ingen';

$text['capacity']       = 'Kapacitet';
  
$text['template']       = 'Skabelon';
$text['language']       = 'Sprog';
$text['submit']         = 'Okay';
$text['created']        = 'Lavet af';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dage';
$text['hours']          = 'timer';
$text['minutes']        = 'minutter';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/da.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: da.php,v 1.19 2006/06/05 11:48:16 bigmichi1 Exp $

# Translated by Jonas Koch Bentzen (understroem.dk).

$text['title']          = 'Systeminformation';

$text['vitals']         = 'Systemenheder';
$text['hostname']       = 'Konisk vrtsnavn';
$text['ip']             = 'IP-adresse, der lyttes p';
$text['kversion']       = 'Kerne-version';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Oppetid';
$text['users']          = 'Antal brugere logget ind lige nu';
$text['loadavg']        = 'Ressourceforbrug - gennemsnit';

$text['hardware']       = 'Hardwareinformation';
$text['numcpu']         = 'Processorer';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cachestrrelse';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'PCI-enheder';
$text['ide']            = 'IDE-enheder';
$text['scsi']           = 'SCSI-enheder';
$text['usb']            = 'USB-enheder';

$text['netusage']       = 'Netvrkstrafik';
$text['device']         = 'Enhed';
$text['received']       = 'Modtaget';
$text['sent']           = 'Afsendt';
$text['errors']         = 'Mislykket/tabt';

$text['memusage']       = 'Hukommelsesforbrug';
$text['phymem']         = 'Fysisk hukommelse';
$text['swap']           = 'Swap';

$text['fs']             = 'Monterede filsystemer';
$text['mount']          = 'Monteret p';
$text['partition']      = 'Partition';

$text['percent']        = 'Procent af kapaciteten';
$text['type']           = 'Type';
$text['free']           = 'Ledig';
$text['used']           = 'Brugt';
$text['size']           = 'Strrelse';
$text['totals']         = 'I alt';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ingen';

$text['capacity']       = 'Kapacitet';
  
$text['template']       = 'Skabelon';
$text['language']       = 'Sprog';
$text['submit']         = 'Okay';
$text['created']        = 'Lavet af';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dage';
$text['hours']          = 'timer';
$text['minutes']        = 'minutter';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
